@@ -1,21 +1,25 @@
 import hmac
 import hashlib
-import json
+from typing import Optional
 
 from .models import WebhookEvent
 
+
 class OnfidoInvalidSignatureError(Exception):
     pass
 
+
 class WebhookEventVerifier:
-    def __init__(self, webhook_token):
+    def __init__(self, webhook_token: str) -> None:
         self.webhook_token = webhook_token
 
-    def read_payload(self, raw_event, signature):
+    def read_payload(self, raw_event: str, signature: str) -> Optional[WebhookEvent]:
         # Compute the the actual HMAC signature from the raw request body.
-        event_signature = hmac.new(key=self.webhook_token.encode("utf-8"),
-                                   msg=raw_event.encode("utf-8"),
-                                   digestmod=hashlib.sha256).hexdigest()
+        event_signature = hmac.new(
+            key=self.webhook_token.encode("utf-8"),
+            msg=raw_event.encode("utf-8"),
+            digestmod=hashlib.sha256,
+        ).hexdigest()
 
         # Compare the signatures (prevent against timing attacks).
         if not hmac.compare_digest(signature, event_signature):
